@@ -14,11 +14,11 @@
 #'   bml <- as_bm_list("RSTATS", font = font)
 #'   bml <- bm_flip(bml, "both")
 #'   bm <- bm_call(bml, cbind, direction = "RTL")
-#'   print(bm, px = px_ascii)
+#'   print(bm)
 #' @export
-bm_call <- function(bm_object, .f, ...) {
-    if (!is.list(bm_object))
-        bm_object <- list(bm_object)
-    l <- c(as.list(bm_object), list(...))
+bm_call <- function(x, .f, ...) {
+    if (!is.list(x))
+        x <- list(x)
+    l <- c(as.list(x), list(...))
     do.call(.f, l)
 }
